@@ -85,6 +85,12 @@ impl Renderer for ItemRenderer {
                         .page
                         + 1;
 
+                    let is_single_page = if let Some(max_rows) = table.max_in_memory_rows {
+                        records_length <= max_rows
+                    } else {
+                        records_length <= self.specs.max_in_memory_rows
+                    };
+
                     let mut reader = generate_reader()
                         .context(format!("Could not read file with path {:?}", &dataset.path))?;
                     let headers = reader.headers()?.iter().map(|s| s.to_owned()).collect_vec();
@@ -144,7 +150,7 @@ impl Renderer for ItemRenderer {
                         dataset.separator,
                         table_specs,
                         additional_headers,
-                        table.pin_columns,
+                        is_single_page,
                     )?;
                     render_plots(
                         &out_path,
@@ -253,7 +259,7 @@ fn render_table_javascript<P: AsRef<Path>>(
     separator: char,
     render_columns: &HashMap<String, RenderColumnSpec>,
     additional_headers: Option<Vec<StringRecord>>,
-    pin_columns: usize,
+    is_single_page: bool,
 ) -> Result<()> {
     let mut templates = Tera::default();
     templates.add_raw_template(
@@ -382,7 +388,7 @@ fn render_table_javascript<P: AsRef<Path>>(
     context.insert("detail_mode", &detail_mode);
     context.insert("link_urls", &link_urls);
     context.insert("num", &numeric);
-    context.insert("pin_columns", &pin_columns);
+    context.insert("is_single_page", &is_single_page);
 
     let file_path = Path::new(output_path.as_ref()).join(Path::new("table").with_extension("js"));
 
@@ -725,11 +731,15 @@ fn render_linkouts(
             let linked_value = match linked_values.index.get(&row[index]) {
                 Some(value) => value,
                 None => {
-                    bail!(TableLinkingError::NotFound {
-                        not_found: row[index].to_string(),
-                        column: linked_column.to_string(),
-                        table: table.to_string(),
-                    })
+                    if !link_specs.optional {
+                        bail!(TableLinkingError::NotFound {
+                            not_found: row[index].to_string(),
+                            column: linked_column.to_string(),
+                            table: table.to_string(),
+                        })
+                    } else {
+                        continue;
+                    }
                 }
             };
             linkouts.push(Linkout {
